@@ -23,12 +23,12 @@
 
 // Qt
 #include <QAction>
-#include <QDesktopWidget>
 #include <QFileDialog>
 #include <QIcon>
 #include <QInputDialog>
 #include <QLabel>
 #include <QPixmapCache>
+#include <QScreen>
 #include <QShortcut>
 #include <QStatusBar>
 #include <QWindowStateChangeEvent>
@@ -185,7 +185,7 @@ void KMahjongg::setupKAction()
 
     // settings
     KStandardAction::preferences(this, SLOT(showSettings()), actionCollection());
-    setupGUI(qApp->desktop()->availableGeometry().size() * 0.7);
+    setupGUI(qApp->primaryScreen()->geometry().size() * 0.7);
 }
 
 void KMahjongg::toggleFullscreen(bool fullscreen)
@@ -312,7 +312,7 @@ void KMahjongg::loadSettings()
         qCDebug(KMAHJONGG_LOG) << "An error occurred when loading the background " << Prefs::background() << " KMahjongg will continue with the default background.";
     }
 
-    // Set wether removed tiles should be shown.
+    // Set whether removed tiles should be shown.
     m_gameView->showRemovedTiles(Prefs::removedTiles());
 
     // Maybe load a new layout and start a new game if the layout or random mode has changed.
